@@ -97,6 +97,12 @@ case "$1" in
             echo ""                                  >> /etc/benno-web/auth.conf
         fi
 
+        # Auth.d config
+        if [ ! -f /etc/benno-web/auth.d/.configured ];then
+            touch /etc/benno-web/auth.d/.configured
+            ln -s /usr/lib/benno-web/benno_dbauth /etc/benno-web/auth.d/50_benno_dbauth
+        fi
+
         # clear cache
         set +e
         if [ -d /var/cache/benno-web/templates_c/default/ ];then
