@@ -95,8 +95,11 @@ function eor ()
 
 // Langage settings
 if ($App->getParam('LANG')) {
-    $App->setLang($App->getParam('LANG'));
-    $App->setSession('LANG',$App->getParam('LANG'));
+    $LANG = $App->getParam('LANG');
+    $App->setLang($LANG);
+    $App->setSession('LANG',$LANG);
+    // set language on change and after login for 32 days
+    setcookie("BENNO_LANGUAGE", $LANG, time()+2764800, dirname($_SERVER['REQUEST_URI']));
 }
 elseif ($App->getSession('LANG')) {
     $App->setLang($App->getSession('LANG'));
@@ -112,7 +115,7 @@ else {
                         false));
     }
 }
-$App->setSkin($App->getConfig('SKINDIR','default'));
+$App->setSkin($App->getConfig('SKINDIR','default'),$header_template);
 
 // fetch user variable from session
 $USER = $App->getSession('USER');
@@ -137,12 +140,17 @@ else {
 }
 
 if (! $CURRENT_ACTION || ! preg_match('/^[a-zA-Z0-9_-]+$/',$CURRENT_ACTION)) {
-    $CURRENT_ACTION = 'default';
+    $CURRENT_ACTION = $default_action;
 }
 
 $App->log("CA $CURRENT_ACTION",2,'SPAF2');
 $App->view = $CURRENT_ACTION;
 
+$tmpAccess = $App->getSession('tmpAccess');
+if ($tmpAccess) {
+    $App->setAuthz($tmpAccess,0);
+}
+
 /* *** PRE CTRL HOOK ***/
 if (file_exists($MODULE.'/pre_ctrl.php')) {
     $App->log("CALL $MODULE/pre_ctrl.php",3,'SPAF2');
@@ -227,12 +235,12 @@ if ($App->getParam('SKIN')) {
 $App->log("TPL $App->view",2,'SPAF2');
 $App->template = $App->view;
 // header and footer relative to template_root
-$App->compile($App->TPL->getTemplateDir(0).'/header.tpl');
+$App->compile($App->TPL->getTemplateDir(0).'/'.$header_template);
 // Append '.tpl' extension
 if (! preg_match('/\.[[:alnum:]]{1,3}$/',$App->template))
      $App->template .= '.tpl';
 $App->compile($App->TPL->getTemplateDir(0).'/'.$App->template);
-$App->compile($App->TPL->getTemplateDir(0).'/footer.tpl');
+$App->compile($App->TPL->getTemplateDir(0).'/'.$footer_template);
 
 // return the response
 $App->display();
