@@ -331,13 +331,6 @@ class Application extends ApplicationConfig
      * Check if the current user is allowed to access the given
 	 * action. Sets the error ERR_AUTHZ if the current user is not authorized
      * to access the given action.
-     *
-	 * If the class method Authorization::check() exists, the method check will
-	 * be called with the $action variable and the current $App object.
-     * The return value of this method will be returned.
-	 * Otherwise the authorization will be checked against the value of the
-	 * authz configuration for this action. If successful a TRUE value will be
-     * returned.
      *
      * @access public
      * @param string $action
@@ -346,11 +339,7 @@ class Application extends ApplicationConfig
     function authz ($action)
     {
         $authorized = FALSE;
-        if (class_exists('Authorization'))
-        {
-            $authorized = Authorization::check($action,$this);
-        }
-        elseif (isset($this->authz[$action])) {
+        if (isset($this->authz[$action])) {
             if ($this->accessLevel() >= $this->authz[$action]) {
                 $authorized = TRUE;
             }
@@ -362,6 +351,25 @@ class Application extends ApplicationConfig
     }
 
 
+    /**
+     * setAuthz
+     *
+     * Set authorization level for the given action in current response.
+     *
+     * @access public
+     * @param string $action
+     * @param string $level
+     * @return previous level
+     */
+    function setAuthz($action,$level)
+    {
+        $prev_level = $this->authz[$action];
+        $this->authz[$action] = $level;
+
+        return $prev_level;
+    }
+
+
     /**
      * Return the value of a configuration parameter.
      *
@@ -674,10 +682,29 @@ class Application extends ApplicationConfig
      */
    function redirect ($action,$plist=array())
     {
+
+        // redirect to another script if "?" given
+        @list($script,$ca) = explode('?',$action);
+        if ($ca) {
+            $redir_to = dirname($_SERVER['SCRIPT_NAME']).'/'.$script;
+            $params .= $ca;
+        }
+        else {
+            $redir_to  = $_SERVER['SCRIPT_NAME'];
+            $params .= 'CA='.$action;
+        }
+
+        if ($this->DEBUG) {
+            $this->log("REDIRECT ===> $redir_to?$params",2,'SPAF2/App');
+            $this->log("------------------------------------------",2,'SPAF2/App');
+        }
+
+        // show sessionid in url
         if ($this->getConfig('URL_SESSIONID') == 'ENABLED') {
             $sidprefix = session_name().'='.session_id().'&';
         }
-        $params = $sidprefix.'CA='.$action;
+        $params .= $sidprefix;
+
 
         if (is_array($plist)) {
             foreach ($plist as $var => $value) {
@@ -687,10 +714,6 @@ class Application extends ApplicationConfig
         else {
             $params .= '&'. $plist;
         }
-        if ($this->DEBUG) {
-            $this->log("REDIRECT ===> $action",2,'SPAF2/App');
-            $this->log("------------------------------------------",2,'SPAF2/App');
-        }
 
         // HTTP HOST
         if (isset($_SERVER['HTTP_X_FORWARDED_HOST'])) {
@@ -720,13 +743,13 @@ class Application extends ApplicationConfig
 
         // HTTP CONFIGURATION
         if ($redirect_base = $this->getConfig('REDIRECT_BASE')) {
-            $location = 'Location: '.$redirect_base.$_SERVER['SCRIPT_NAME']."?$params";
+            $location = 'Location: '.$redirect_base.$redir_to."?$params";
         }
         else {
             if ($http_port) {
                 $http_host = $http_host.':'.$http_port;
             }
-            $location = 'Location: '.$http_proto.$http_host.$_SERVER['SCRIPT_NAME']."?$params";
+            $location = 'Location: '.$http_proto.$http_host.$redir_to."?$params";
         }
 
         header($location);
@@ -887,14 +910,14 @@ class Application extends ApplicationConfig
      * @access public
      * @param $skin string
      */
-    function setSkin($skindir='')
+    function setSkin($skindir='',$header_template='header.tpl')
     {
         if (!$skindir) {
             $skindir = 'default';
         }
         $this->skin = $skindir;
         $tpl_dir  = $this->tpl_root.'/'.$skindir;
-        if (!is_file($tpl_dir.'/header.tpl')) {
+        if (!is_file($tpl_dir.'/'.$header_template)) {
             $this->log("Warning: Skin $tpl_dir not initialized.",2,'spaf2/app');
             $tpl_dir = $this->tpl_root.'/default';
         }
