@@ -32,7 +32,7 @@
  */
 
 $RESTconf = new ApplicationConfig($App->configdir);
-$RESTConf->load($App->getConfig('REST_CONFIG','rest.conf'));
+$RESTconf->load($App->getConfig('REST_CONFIG','rest.conf'));
 
 // defaults: compatibility to deprecated configuration
 $base_url  = $RESTconf->getConfig('BASE_URL','http://localhost:21080');
@@ -144,4 +144,4 @@ if(curl_error($curl)){
 }
 curl_close($curl);
 
-?>
+?>
\ No newline at end of file
